changeset 9629:3c98f3e1b719 libavcodec

Fix bandwith vs. bandwiDth typo.
author diego
date Tue, 12 May 2009 23:40:22 +0000
parents 4b6766057548
children ef0cf18b192d
files qcelpdata.h qcelpdec.c
diffstat 2 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/qcelpdata.h	Tue May 12 19:56:48 2009 +0000
+++ b/qcelpdata.h	Tue May 12 23:40:22 2009 +0000
@@ -557,6 +557,6 @@
  *
  * TIA/EIA/IS-733 2.4.3.3.6 6
  */
-#define QCELP_BANDWITH_EXPANSION_COEFF 0.9883
+#define QCELP_BANDWIDTH_EXPANSION_COEFF 0.9883
 
 #endif /* AVCODEC_QCELPDATA_H */
--- a/qcelpdec.c	Tue May 12 19:56:48 2009 +0000
+++ b/qcelpdec.c	Tue May 12 23:40:22 2009 +0000
@@ -597,7 +597,7 @@
  * @param lspf line spectral pair frequencies
  * @param lpc linear predictive coding coefficients
  *
  * @note: bandwith_expansion_coeff could be precalculated into a table
  *        but it seems to be slower on x86
  *
  * TIA/EIA/IS-733 2.4.3.3.5
@@ -605,7 +605,7 @@
 static void lspf2lpc(const float *lspf, float *lpc)
 {
     double lsf[10];
-    double bandwith_expansion_coeff = QCELP_BANDWITH_EXPANSION_COEFF;
+    double bandwidth_expansion_coeff = QCELP_BANDWIDTH_EXPANSION_COEFF;
     int   i;
 
     for (i=0; i<10; i++)
@@ -615,8 +615,8 @@
 
     for (i=0; i<10; i++)
     {
-        lpc[i] *= bandwith_expansion_coeff;
-        bandwith_expansion_coeff *= QCELP_BANDWITH_EXPANSION_COEFF;
+        lpc[i] *= bandwidth_expansion_coeff;
+        bandwidth_expansion_coeff *= QCELP_BANDWIDTH_EXPANSION_COEFF;
     }
 }
@@ -597,7 +597,7 @@
  * @param lpc linear predictive coding coefficients
  *
- * @note: bandwith_expansion_coeff could be precalculated into a table
+ * @note: bandwidth_expansion_coeff could be precalculated into a table
  *        but it seems to be slower on x86
  *